@@ -88,9 +88,6 @@ def D(elemento,color = "black"):#Por default se imprime en rojo, para indicar qu
     texto = a + b + c
       #texto = texto.replace("text", Estilo)
     IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
-    print(Documento)
-    print(Documento + " /n"+str(texto))
-    #Documento += " /n" + str(texto)
     Documento.append(texto)
 
 #def E(expr,color = "red"):
